@@ -1,3 +1,7 @@
+import os
+import platform
+import subprocess
+
 import plagdef.gui.main as main
 from plagdef.gui.views import HomeView, LoadingView, NoResultsView, ErrorView, ResultView, \
     FileDialog, MatchesDialog
@@ -97,7 +101,7 @@ class ResultController:
 
     def _connect_slots(self):
         self.view.register_for_signals(self._on_again, self.on_select_pair)
-        self.matches_dialog.register_for_signals(self.on_prev_match, self.on_next_match)
+        self.matches_dialog.register_for_signals(self.on_prev_match, self.on_next_match, self.on_doc_name_click)
 
     def _on_again(self):
         main.app.window.switch_to(HomeView)
@@ -110,3 +114,11 @@ class ResultController:
 
     def on_next_match(self):
         self.matches_dialog.next_match()
+
+    def on_doc_name_click(self, path: str):
+        if platform.system() == 'Darwin':  # macOS
+            subprocess.call(('open', path))
+        elif platform.system() == 'Windows':  # Windows
+            os.startfile(path)
+        else:  # linux variants
+            subprocess.call(('xdg-open', path))
